\name{verifyInput}
\alias{verifyInput}
\title{asks a question and waits for valid input.}
\usage{
  verifyInput(question, ..., extraArgs = list())
}
\arguments{
  \item{question}{the question to ask the user}

  \item{...}{the list of valid inputs to chose from, of the
  form \code{input=action}. This is the same sort of input
  that should be fed into \code{\link[base]{switch}}. All
  arguments must be names, except possibly one to be used
  as the default value (which must occur last). See
  details.}

  \item{extraArgs}{a *list* of extra arguments to pass to
  the function that gets chosen from \code{...}. The format
  of the list is as for \code{\link[base]{do.call}}.}
}
\value{
  the value of one of the elements of \code{...}.
}
\description{
  This is a bit like \code{\link[utils]{menu}} except it
  doesn't display the choices as \code{1: xx 2: xx} etc.
  Suitable for yes/no questions where 'menu' is a bit too
  much.
}
\details{
  The answer to \code{question} is collected as a string
  using \code{\link[base]{readline}}.

  This is then fed (in string form) to
  \code{\link[base]{switch}} with the \code{...} arguments:
  \code{switch( readline(question), ... )}.

  As such, the default argument (if any) must go last.

  The argument that is selected is: \itemize{ \item
  evaluated via \code{do.call(arg,extraArgs)}, if it is a
  function.  \item simply returned, otherwise. } The output
  of this is returned as the output of the function.
}
\examples{
\dontrun{
# example of setting a parameter via a yes/no question:
p <- 1
p <- verifyInput( sprintf('current value of p is \%i, keep? [Y/N] ',p),
                  Y=,y=p,                    # return p if they keep
                  N=,n= function() readline('Enter new value for p: '))
# If the user says 'N' they enter a new value for p and this is
# returned.
}
}

